@@ -234,68 +234,3 @@ impl<T: AsMut<[U]>, U> AsMut<[U]> for Aligned<T> {
         self.0.as_mut()
     }
 }
-
-#[macro_export]
-macro_rules! project_struct {
-    ($struct:ident: $ty:path => $field:tt) => {
-        #[allow(unused_unsafe)]
-        (unsafe {
-            &mut *($struct as &mut MaybeUninit<$ty>)
-                .as_mut_ptr()
-                .cast::<u8>()
-                .add($crate::offset_of!($ty, $field))
-                .cast()
-        })
-    };
-    ($struct:ident: $struct_ty:path => $field:tt: $field_ty:path) => {
-        #[allow(unused_unsafe)]
-        (unsafe {
-            &mut *($struct as &mut MaybeUninit<$struct_ty>)
-                .as_mut_ptr()
-                .cast::<u8>()
-                .add($crate::offset_of!($struct_ty, $field))
-                .cast::<MaybeUninit<$field_ty>>()
-        })
-    };
-}
-
-#[macro_export]
-macro_rules! project_tuple {
-    ($tuple:ident: $ty:path => $index:tt) => {
-        (unsafe {
-            &mut *($tuple as &mut MaybeUninit<$ty>)
-                .as_mut_ptr()
-                .cast::<u8>()
-                .add(memoffset::offset_of_tuple!($ty, $index))
-                .cast()
-        })
-    };
-    ($tuple:ident: $tuple_ty:path => $index:tt: $index_ty:path) => {
-        (unsafe {
-            &mut *($tuple as &mut MaybeUninit<$tuple_ty>)
-                .as_mut_ptr()
-                .cast::<u8>()
-                .add(memoffset::offset_of_tuple!($tuple_ty, $index))
-                .cast::<MaybeUninit<$index_ty>>()
-        })
-    };
-}
-
-#[macro_export]
-macro_rules! resolve_struct {
-    ($out:ident = |$pos:ident, $resolver:ident| -> $out_ty:path { $($field:ident: $field_expr:expr),* }) => {
-        resolve_struct!($out = |$pos, $resolver| -> $out_ty { $($field: $field_expr,)* });
-    };
-    ($out:ident = |$pos:ident, $resolver:ident| -> $out_ty:path { $($field:ident: $field_expr:expr,)* }) => {
-        $(
-            unsafe {
-                let field_offset = memoffset::offset_of!($out_ty, $field);
-                $field_expr.resolve(
-                    $pos + field_offset,
-                    $resolver.$field,
-                    &mut *$out.as_mut_ptr().cast::<u8>().add(field_offset).cast()
-                );
-            }
-        )*
-    };
-}
